@@ -2,6 +2,7 @@ from typing import Union
 
 from scipy.stats import binom, rv_discrete
 
+from compound_types.built_ins import FloatIterable
 from probability.distributions.mixins.attributes import NIntDMixin, PFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import \
@@ -52,6 +53,33 @@ class Binomial(
     def upper_bound(self) -> int:
         return self._n
 
+    @staticmethod
+    def fit(data: FloatIterable) -> 'Binomial':
+        """
+        Fit a Binomial distribution to the data from a single experiment using
+        the maximum likelihood estimate for p.
+
+        https://en.wikipedia.org/wiki/Binomial_distribution#Estimation_of_parameters
+
+        :param data: Iterable of data of to fit to. Each value should be 0 or 1.
+        """
+        n = len(data)
+        k = sum(data)
+        return Binomial(n=n, p=k / n)
+
+    @staticmethod
+    def fits(data: FloatIterable, n: int) -> 'Binomial':
+        """
+        Fit a Binomial distribution to the distribution of results of a series
+        of experiments using the maximum likelihood estimate for p.
+
+        :param data: Iterable of data to fit to.
+        :param n: Number of trials.
+        """
+        N = n * len(data)
+        k = sum(data)
+        return Binomial(n=n, p=k / N)
+
     def __str__(self):
 
         return (
